@@ -7,20 +7,22 @@
  */
 
 #include <Akonadi/Collection>
+using namespace Qt::Literals::StringLiterals;
+
 #include <KContacts/Addressee>
 #include <KContacts/ContactGroup>
 #include <QDir>
 #include <QTest>
 
+#include "../agent/akonotesindexer.h"
+#include "../agent/calendarindexer.h"
+#include "../agent/contactindexer.h"
+#include "../agent/emailindexer.h"
+#include "../search/calendar/calendarsearchstore.h"
+#include "../search/contact/contactsearchstore.h"
+#include "../search/email/emailsearchstore.h"
+#include "../search/note/notesearchstore.h"
 #include "searchplugin.h"
-#include <../agent/akonotesindexer.h>
-#include <../agent/calendarindexer.h>
-#include <../agent/contactindexer.h>
-#include <../agent/emailindexer.h>
-#include <../search/calendar/calendarsearchstore.h>
-#include <../search/contact/contactsearchstore.h>
-#include <../search/email/emailsearchstore.h>
-#include <../search/note/notesearchstore.h>
 #include <Akonadi/MessageFlags>
 #include <Akonadi/SearchQuery>
 
@@ -60,11 +62,11 @@ private:
 private Q_SLOTS:
     void initTestCase()
     {
-        emailDir = QDir::tempPath() + QLatin1String("/searchplugintest/email/");
-        emailContactsDir = QDir::tempPath() + QLatin1String("/searchplugintest/emailcontacts/");
-        contactsDir = QDir::tempPath() + QLatin1String("/searchplugintest/contacts/");
-        noteDir = QDir::tempPath() + QLatin1String("/searchplugintest/notes/");
-        calendarDir = QDir::tempPath() + QLatin1String("/searchplugintest/calendar/");
+        emailDir = QDir::tempPath() + "/searchplugintest/email/"_L1;
+        emailContactsDir = QDir::tempPath() + "/searchplugintest/emailcontacts/"_L1;
+        contactsDir = QDir::tempPath() + "/searchplugintest/contacts/"_L1;
+        noteDir = QDir::tempPath() + "/searchplugintest/notes/"_L1;
+        calendarDir = QDir::tempPath() + "/searchplugintest/calendar/"_L1;
 
         QDir dir;
         QVERIFY(QDir(QDir::tempPath() + QStringLiteral("/searchplugintest")).removeRecursively());
@@ -106,13 +108,14 @@ private Q_SLOTS:
         }
         {
             KMime::Message::Ptr msg(new KMime::Message);
+            msg->contentType()->setMimeType("multipart/mixed");
             msg->subject()->from7BitString("subject2");
 
             // Multipart message
             auto b = new KMime::Content;
             b->contentType()->setMimeType("text/plain");
             b->setBody("body2");
-            msg->addContent(b, true);
+            msg->prependContent(b);
 
             msg->from()->addAddress("john@test.com", QStringLiteral("John Doe"));
             msg->to()->addAddress("jane@test.com", QStringLiteral("Jane Doe"));
@@ -130,13 +133,14 @@ private Q_SLOTS:
         }
         {
             KMime::Message::Ptr msg(new KMime::Message);
+            msg->contentType()->setMimeType("multipart/mixed");
             msg->subject()->from7BitString("subject3");
 
             // Multipart message
             auto b = new KMime::Content;
             b->contentType()->setMimeType("text/plain");
             b->setBody("body3");
-            msg->addContent(b, true);
+            msg->prependContent(b);
 
             msg->from()->addAddress("john@test.com", QStringLiteral("John Doe"));
             msg->to()->addAddress("jane@test.com", QStringLiteral("Jane Doe"));
@@ -154,13 +158,14 @@ private Q_SLOTS:
         }
         {
             KMime::Message::Ptr msg(new KMime::Message);
+            msg->contentType()->setMimeType("multipart/mixed");
             msg->subject()->from7BitString("subject4");
 
             // Multipart message
             auto b = new KMime::Content;
             b->contentType()->setMimeType("text/plain");
             b->setBody("body4");
-            msg->addContent(b, true);
+            msg->prependContent(b);
 
             msg->from()->addAddress("john_blue@test.com", QStringLiteral("John Doe"));
             msg->to()->addAddress("jane@test.com", QStringLiteral("Jane Doe"));
@@ -187,13 +192,14 @@ private Q_SLOTS:
         }
         {
             KMime::Message::Ptr msg(new KMime::Message);
+            msg->contentType()->setMimeType("multipart/mixed");
             msg->subject()->from7BitString("all tags");
 
             // Multipart message
             auto b = new KMime::Content;
             b->contentType()->setMimeType("text/plain");
             b->setBody("tags");
-            msg->addContent(b, true);
+            msg->prependContent(b);
 
             msg->from()->addAddress("john@test.com", QStringLiteral("John Doe"));
             msg->to()->addAddress("jane@test.com", QStringLiteral("Jane Doe"));
@@ -222,12 +228,13 @@ private Q_SLOTS:
         {
             KMime::Message::Ptr msg(new KMime::Message);
             msg->subject()->from7BitString("Change in qt/qtx11extras[stable]: remove QtWidgets dependency");
+            msg->contentType()->setMimeType("multipart/mixed");
 
             // Multipart message
             auto b = new KMime::Content;
             b->contentType()->setMimeType("text/plain");
             b->setBody("body5");
-            msg->addContent(b, true);
+            msg->prependContent(b);
 
             msg->from()->addAddress("john@test.com", QStringLiteral("John Doe"));
             msg->to()->addAddress("jane@test.com", QStringLiteral("Jane Doe"));
@@ -319,13 +326,14 @@ private Q_SLOTS:
         // Note item
         {
             KMime::Message::Ptr msg(new KMime::Message);
+            msg->contentType()->setMimeType("multipart/mixed");
             msg->subject()->from7BitString("note");
 
             // Multipart message
             auto b = new KMime::Content;
             b->contentType()->setMimeType("text/plain");
             b->setBody("body note");
-            msg->addContent(b, true);
+            msg->prependContent(b);
             msg->assemble();
 
             Akonadi::Item item(QStringLiteral("text/x-vnd.akonadi.note"));
@@ -338,13 +346,14 @@ private Q_SLOTS:
         }
         {
             KMime::Message::Ptr msg(new KMime::Message);
+            msg->contentType()->setMimeType("multipart/mixed");
             msg->subject()->from7BitString("note2");
 
             // Multipart message
             auto b = new KMime::Content;
             b->contentType()->setMimeType("text/plain");
             b->setBody("note");
-            msg->addContent(b, true);
+            msg->prependContent(b);
             msg->assemble();
 
             Akonadi::Item item(QStringLiteral("text/x-vnd.akonadi.note"));
@@ -357,13 +366,14 @@ private Q_SLOTS:
         }
         {
             KMime::Message::Ptr msg(new KMime::Message);
+            msg->contentType()->setMimeType("multipart/mixed");
             msg->subject()->from7BitString("note3");
 
             // Multipart message
             auto b = new KMime::Content;
             b->contentType()->setMimeType("text/plain");
             b->setBody("note3");
-            msg->addContent(b, true);
+            msg->prependContent(b);
             msg->assemble();
 
             Akonadi::Item item(QStringLiteral("text/x-vnd.akonadi.note"));
